ActiveRegion

Struct ActiveRegion 

pub struct ActiveRegion {
    pub e_up: EdgeIdx,
    pub node_up: NodeIdx,
    pub winding_number: i32,
    pub inside: bool,
    pub sentinel: bool,
    pub dirty: bool,
    pub fix_upper_edge: bool,
}
An active region: the area between two adjacent edges crossing the sweep line.

Fields

e_up: EdgeIdx

Upper edge (directed right to left).

node_up: NodeIdx

Node in the edge dictionary for this region.

winding_number: i32

Running winding number for the region.

inside: bool

Is this region inside the polygon?

sentinel: bool

Sentinel: marks fake edges at t = ±infinity.

dirty: bool

Dirty: upper or lower edge changed, need to check for intersection.

fix_upper_edge: bool

Temporary edge introduced for a right vertex (will be fixed later).