pub struct ActiveRegion {
pub e_up: EdgeIdx,
pub node_up: NodeIdx,
pub winding_number: i32,
pub inside: bool,
pub sentinel: bool,
pub dirty: bool,
pub fix_upper_edge: bool,
}Expand description
An active region: the area between two adjacent edges crossing the sweep line.
Fields
e_up: EdgeIdxUpper edge (directed right to left).
node_up: NodeIdxNode in the edge dictionary for this region.
winding_number: i32Running winding number for the region.
inside: boolIs this region inside the polygon?
sentinel: boolSentinel: marks fake edges at t = ±infinity.
dirty: boolDirty: upper or lower edge changed, need to check for intersection.
fix_upper_edge: boolTemporary edge introduced for a right vertex (will be fixed later).